@@ -2,7 +2,7 @@
 
 ;; Author:  Peter Breton <pbreton@cs.umb.edu>
 ;; Created: Sun Mar 16 1997
-;; Version: $Id: net-utils.el,v 1.5 1998/03/11 00:27:18 pbreton Exp pbreton $
+;; Version: $Id: net-utils.el,v 1.1 1998/03/26 03:39:21 steveb Exp $
 ;; Keywords: 
 ;; Time-stamp: <1998-03-19 19:14:35 pbreton>
 
@@ -22,6 +22,9 @@
 
 ;;; Change log:
 ;; $Log: net-utils.el,v $
+;; Revision 1.1  1998/03/26 03:39:21  steveb
+;; New file net-utils.el.
+;;
 ;; Revision 1.5  1998/03/11 00:27:18  pbreton
 ;; Changed name to net-utils
 ;; Added AUTOLOAD comments
@@ -66,10 +69,10 @@
 (eval-when-compile
   (require 'comint))
 
-(defconst net-utils-version (substring "$Revision: 1.5 $" 11 -2)
+(defconst net-utils-version (substring "$Revision: 1.1 $" 11 -2)
   "The version number of net-utils (as string).  The complete RCS id is:
 
-  $Id: net-utils.el,v 1.5 1998/03/11 00:27:18 pbreton Exp pbreton $")
+  $Id: net-utils.el,v 1.1 1998/03/26 03:39:21 steveb Exp $")
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Customization Variables
